<?php

namespace Ems\Logic\Offline;

use Util\Repositories;

class OfflineTimeRegister extends OfflineEntity {
    
    /* @var string */
    private $nrVinculo;
    /* @var OfflineClockIn[] */
    private $clockIns;
    
    public function __construct(string $nrVinculo, array $clockIns) {
        $this->nrVinculo = $nrVinculo;
        $this->clockIns = $clockIns;
    }
    
    public static function fromArray(?array $row) {
        $rowClockIns = $row['offlineClockIns'] ?? [];
        $nrVinculo = $row['NRVINCULOM'] ?? null;
        $clockIns = [];
        foreach ($rowClockIns as $rowClockIn) {
            $newClockIn = OfflineClockIn::fromArray(self::prepareClockInRow($nrVinculo, $rowClockIn));
            $clockIns[] = $newClockIn;
        }
        
        return new OfflineTimeRegister($nrVinculo, $clockIns);
    }
    
    public function synchronizeClockIns(): void {
        $this->throwExceptionIfOfflineNotPermitted();
        foreach ($this->clockIns as $clockIn) {
            $clockIn->synchronize();
        }
    }
    
    public function synchronize(): void {
        $this->throwExceptionIfOfflineNotPermitted();
        
        $this->getEntityManager()->beginTransaction();
        try {
            $this->synchronizeClockIns();
            $this->getEntityManager()->flush();
            $this->getEntityManager()->commit();
        } catch (\Exception $e) {
            $this->getEntityManager()->rollback();    
            throw $e;
        }
    }
    
    private function throwExceptionIfOfflineNotPermitted() {
        if ($this->isOfflineNotPermitted()) {
            OfflineException::offlineNotPermitted();
        }
    }
    
    private function isOfflineNotPermitted() {
        $pontoAcessoVinculo = $this->getEntityManager()->getRepository(Repositories::GPE_PONTOACESSO)->getPontoAcessoVinculo(
            $this->getNrorg(),
            $this->nrVinculo
        );
        
        if (empty($pontoAcessoVinculo)) {
            return true;
        }
        
        return $pontoAcessoVinculo->getIdmarcoffline() !== 'S';
    }
    
    private static function prepareClockInRow(?string $nrVinculo, ?array $row): ?array {
        $row['nrVinculo'] = $nrVinculo;
        return $row;
    }
}