/* Tabela MOVCAIXA: Tabela de Movimentao do Caixa */
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes na tabela MOVCAIXA
              referentes s operaes na rotina de Fechamento do Cupom */
/* Objetivo: Gerar um log que vai registrar as alteraes na tabela de Movimentao do Caixa que possam
             interferir na rotina de Fechamento de Cupom, utilizando a tabela Geral de Logs de Operaes */
CREATE OR REPLACE TRIGGER LOG_FIS_MOVCAIXA
AFTER DELETE OR INSERT OR UPDATE
ON MOVCAIXA FOR EACH ROW
DECLARE
   V_DSREMOTEADDR VARCHAR2(50);
   V_DSREMOTEHOST VARCHAR2(50);
   V_DSSERVERRDM  VARCHAR2(20);
   V_DSSERVMETHOD VARCHAR2(50);
   V_DSREMOTEOPER VARCHAR2(12);
   V_NMOPERADOR   VARCHAR2(100);
   V_TIPO         VARCHAR2(1);
   V_DESC         VARCHAR2(1000);
   V_CDFILLOGOPER VARCHAR2(4);
   V_ITPESQ       VARCHAR2(40);
   V_DTOPER       DATE;
   V_STATUS       VARCHAR2(10);
BEGIN
   V_TIPO := '0';
   V_DESC := '';
   V_CDFILLOGOPER := '';

   IF DELETING THEN
      V_TIPO         := '3';
      IF :OLD.CDFILIALNF IS NOT NULL THEN
         V_DESC := V_DESC || 'CdFilial=' || :OLD.CDFILIALNF;
      END IF;
      IF :OLD.NRLANCTONF IS NOT NULL THEN
         V_DESC := V_DESC || ' NrLancNf=' || :OLD.NRLANCTONF;
      END IF;
      IF :OLD.CDFILIALNFFIS IS NOT NULL THEN
         V_DESC := V_DESC || ' CdFilialFis=' || :OLD.CDFILIALNFFIS;
      END IF;
      IF :OLD.NRLANCTONFFIS IS NOT NULL THEN
         V_DESC := V_DESC || ' NrLancNfFis=' || :OLD.NRLANCTONFFIS;
      END IF;
      IF :OLD.IDAPROVREDZNFCE = 'A' THEN
         V_DESC := V_DESC || ' IdAprovacao=' || :OLD.IDAPROVREDZNFCE;
      END IF;
   ELSIF UPDATING THEN
      V_TIPO         := '2';
      IF NVL(:NEW.CDFILIALNF, '!') <> NVL(:OLD.CDFILIALNF, '!') THEN
         V_DESC := V_DESC || 'CdFilial=' || :NEW.CDFILIALNF;
      END IF;
      IF NVL(:NEW.NRLANCTONF, '!') <> NVL(:OLD.NRLANCTONF, '!') THEN
         V_DESC := V_DESC || ' NrLancNf=' || :NEW.NRLANCTONF;
      END IF;
      IF NVL(:NEW.CDFILIALNFFIS, '!') <> NVL(:OLD.CDFILIALNFFIS, '!') THEN
         V_DESC := V_DESC || ' CdFilialFis=' || :NEW.CDFILIALNFFIS;
      END IF;
      IF NVL(:NEW.NRLANCTONFFIS, '!') <> NVL(:OLD.NRLANCTONFFIS, '!') THEN
         V_DESC := V_DESC || ' NrLancNfFis=' || :NEW.NRLANCTONFFIS;
      END IF;
      IF NVL(:NEW.IDAPROVREDZNFCE, '!') <> NVL(:OLD.IDAPROVREDZNFCE, '!') THEN
         V_DESC := V_DESC || ' IdAprovacao=' || :NEW.IDAPROVREDZNFCE;
      END IF;
   END IF;

   V_ITPESQ := :OLD.CDFILIAL||:OLD.CDCAIXA||TO_CHAR(:OLD.DTMOVIMCAIXA,'DDMMYYYY')||:OLD.NRSEQVENDA;

   IF  V_TIPO <> '0' THEN
       NMUSUARIO(V_NMOPERADOR);
       WEBTUNNING(V_DSREMOTEADDR,
                  V_DSREMOTEHOST,
                  V_DSSERVERRDM,
                  V_DSSERVMETHOD,
                  V_DSREMOTEOPER);

       IF NOT V_DESC IS NULL THEN
         IF NOT V_NMOPERADOR IS NULL THEN
            V_DTOPER := SYSDATE;
            INSERT INTO LOGOPERA
               (NMTABELA,     DTOPERACAO,   NMRESPOPER,   IDTIPOOPER,  CDPESQITEM,  DSOPERACAO,
                CDFILLOGOPER, DSRDMUSUOPER, DSENDUSUOPER, DSNMUSUOPER, DSMETUSUOPER,CDORESPOPER)
            VALUES
               ('MOVCAIXA',    V_DTOPER,      V_NMOPERADOR,   V_TIPO,         V_ITPESQ,       SUBSTR(V_DESC,1,700),
                V_CDFILLOGOPER, V_DSSERVERRDM, V_DSREMOTEADDR, V_DSREMOTEHOST, V_DSSERVMETHOD, V_DSREMOTEOPER);
         END IF;
       END IF;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('LOG_FIS_MOVCAIXA','6.06.000'); END;
/
