/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: QTDE_BRUTA_PRODUTO.SQL

Descrio:
Retorna a quantidade bruta de um produto a partir da quantidade na receita
de acordo com os parmetros de utilizao do fator de correo e coco.

Criao:
20/01/99 - Ederson

OBS: Convertida para SQL SERVER por Robert Pereira

Manutenes:
__/__/99 - _______ - ___________

P_CDFILIAL   - Cdigo da Filial (utilizado para pesquisar os parmetros
               de utilizao dos fatores de correo e coco.
P_QTORIGINAL - Quantidade Original (lquida).
P_VRPEFATCOC - Fator de Coco.
P_VRPEFATCOR - Fator de Correo.

*/
IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'QTDE_BRUTA_PRODUTO'  AND
	        TYPE = 'P' 			        AND
	        U.UID = O.UID             		        AND
	        U.NAME = USER)


  DROP PROCEDURE QTDE_BRUTA_PRODUTO
  GO
IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'QTDE_BRUTA_PRODUTO'  AND
	        TYPE = 'FN' 			        AND
	        U.UID = O.UID             		        AND
	        U.NAME = USER)


  DROP FUNCTION QTDE_BRUTA_PRODUTO
  GO

CREATE FUNCTION QTDE_BRUTA_PRODUTO(
  @P_CDFILIAL     VARCHAR(4),
  @P_QTORIGINAL   NUMERIC(15,6),
  @P_VRPEFATCOC   NUMERIC(15,6),
  @P_VRPEFATCOR   NUMERIC(15,6),
  @P_IDUTILFATCOC VARCHAR(1) = ' ',
  @P_IDUTILFATCOR VARCHAR(1) = ' ',
  @P_IDTIPCALCFAT VARCHAR(1) = ' ') RETURNS NUMERIC(15,6)

AS BEGIN
   DECLARE @V_QTDECALC NUMERIC;
   DECLARE @V_IDUTILFATCOC  VARCHAR(1);
   DECLARE @V_IDUTILFATCOR  VARCHAR(1);
   DECLARE @V_IDTIPCALCFAT  VARCHAR(1);

   DECLARE C_PARAMPLANEJA CURSOR FOR
   SELECT
      IDUTILFATCOR,
      IDUTILFATCOC,
      IDTIPCALCFAT
   FROM
      PARAMPLANEJA
   WHERE
      (CDFILIAL = @P_CDFILIAL);

   /* - Inicializa os indentificadores com os valores default --------------- */

   IF @P_IDUTILFATCOR = ' '
   BEGIN
      OPEN C_PARAMPLANEJA;

      FETCH NEXT FROM C_PARAMPLANEJA
      INTO @V_IDUTILFATCOR,
           @V_IDUTILFATCOC,
           @V_IDTIPCALCFAT;

      IF @@FETCH_STATUS = -1
      BEGIN
         SET @V_IDUTILFATCOC = 'S';
         SET @V_IDUTILFATCOR = 'S';
         SET @V_IDTIPCALCFAT = 'T';
      END;

   END
   ELSE
   BEGIN
      SET @V_IDUTILFATCOC = @P_IDUTILFATCOC;
      SET @V_IDUTILFATCOR = @P_IDUTILFATCOR;
      SET @V_IDTIPCALCFAT = @P_IDTIPCALCFAT;
   END;

   /* Faz a converso da unidade do produto na receita */

   SET @V_QTDECALC = @P_QTORIGINAL;

   IF (@V_IDTIPCALCFAT <> 'S')
   BEGIN
      IF (@V_IDUTILFATCOR <> 'N') AND (@V_IDUTILFATCOC = 'N')
      BEGIN
         SET @V_QTDECALC = @P_QTORIGINAL * (100 / (100 - @P_VRPEFATCOR));
      END;
      IF (@V_IDUTILFATCOR = 'N') AND (@V_IDUTILFATCOC <> 'N')
      BEGIN
         SET @V_QTDECALC = @P_QTORIGINAL * (100 / (100 + @P_VRPEFATCOC));
      END;
      IF (@V_IDUTILFATCOR <> 'N') AND (@V_IDUTILFATCOC <> 'N')
      BEGIN
         SET @V_QTDECALC = @P_QTORIGINAL * (100 / (100 + @P_VRPEFATCOC));
         SET @V_QTDECALC = @V_QTDECALC * (100 / (100 - @P_VRPEFATCOR));
      END;
   END
   ELSE
   BEGIN
      IF (@V_IDUTILFATCOR <> 'N') AND (@V_IDUTILFATCOC = 'N')
      BEGIN
         SET @V_QTDECALC = @P_QTORIGINAL * (1 + (@P_VRPEFATCOR / 100));
      END;
      IF (@V_IDUTILFATCOR = 'N') AND (@V_IDUTILFATCOC <> 'N')
      BEGIN
         SET @V_QTDECALC = @P_QTORIGINAL * (1 + (@P_VRPEFATCOC / 100));
      END;
      IF (@V_IDUTILFATCOR <> 'N') AND (@V_IDUTILFATCOC <> 'N')
      BEGIN
         SET @V_QTDECALC = @P_QTORIGINAL * (1 + (@P_VRPEFATCOC / 100));
         SET @V_QTDECALC = @V_QTDECALC * (1 + (@P_VRPEFATCOR / 100));
      END;
   END;

   DEALLOCATE C_PARAMPLANEJA;

   RETURN(@V_QTDECALC);
END
GO

--GRANT EXECUTE ON QTDE_BRUTA_PRODUTO TO PUBLIC
--GO

--sp_dbcmptlevel 'TECNISA', @new_cmptlevel = 60

-- VERSAO --
EXEC ATUVEROBJ 'QTDE_BRUTA_PRODUTO','4.05.133';
GO

